==> share-file-systems-0.2.19.tgz: package/js/lib/browser/utilities/webSocket.js <==
/* lib/browser/utilities/webSocket - Handles web socket events and associated errors. This where most communications from outside the browser are processed. */ import browser from "./browser.js";
import network from "./network.js";
const webSocket = {
    error: function browser_utilities_socketError() {
        setTimeout(function browser_utilities_socketError_delay() {
            webSocket.start(null, webSocket.hash);
        }, browser.data.statusTime);
    },
    hash: "",
    send: null,
    sock: function browser_utilities_socket() {
        // A minor security circumvention.
        const socket = WebSocket;
        // eslint-disable-next-line
        WebSocket = null;
        return socket;
    }(),
    start: function browser_utilities_webSocket(callback, hashDevice) {
        const title = document.getElementById("title-bar"), scheme = location.protocol === "http:" ? "ws" : "wss", socket = new webSocket.sock(`${scheme}://localhost:${browser.localNetwork.wsPort}/`, [
            `browser-${hashDevice}`
        ]), open = function browser_utilities_webSocket_socketOpen() {
            if (title.getAttribute("class") === "title offline") {
                location.reload();
            } else {
                title.setAttribute("class", "title");
                browser.socket = socket;
                if (callback !== null) {
                    callback();
                }
            }
        }, close = function browser_utilities_webSocket_socketClose() {
            if (browser.data.hashDevice !== "") {
                const device = document.getElementById(browser.data.hashDevice), agentList = document.getElementById("agentList"), active = agentList.getElementsByClassName("status-active");
                let a = active.length, parent;
                if (a > 0) {
                    do {
                        a = a - 1;
                        parent = active[a].parentNode;
                        parent.setAttribute("class", "offline");
                    }while (a > 0)
                }
                browser.socket = null;
                title.setAttribute("class", "title offline");
                title.getElementsByTagName("h1")[0].innerHTML = "Disconnected.";
                webSocket.send = null;
                if (device !== null) {
                    device.setAttribute("class", "offline");
                }
            }
        }, message = function browser_utilities_socketMessage(event) {
            if (typeof event.data !== "string") {
                return;
            }
            network.receive(event.data);
        };
        webSocket.hash = hashDevice;
        /* Handle Web Socket responses */ socket.onopen = open;
        socket.onmessage = message;
        socket.onclose = close;
        socket.onerror = webSocket.error;
        webSocket.send = function browser_utilities_webSocket_sendWrapper(data) {
            // connecting
            if (socket.readyState === 0) {
                setTimeout(function browser_utilities_webSocket_sendWrapper_delay() {
                    browser_utilities_webSocket_sendWrapper(data);
                }, 10);
            }
            // open
            if (socket.readyState === 1) {
                socket.send(JSON.stringify(data));
            }
        };
    }
};
export default webSocket;

==> share-file-systems-0.2.20.tgz: package/js/lib/browser/utilities/webSocket.js <==
/* lib/browser/utilities/webSocket - Handles web socket events and associated errors. This where most communications from outside the browser are processed. */ import browser from "./browser.js";
import network from "./network.js";
const webSocket = {
    error: function browser_utilities_socketError() {
        setTimeout(function browser_utilities_socketError_delay() {
            webSocket.start(null, webSocket.hash);
        }, browser.data.statusTime);
    },
    hash: "",
    send: null,
    sock: function browser_utilities_socket() {
        // A minor security circumvention.
        const socket = WebSocket;
        // eslint-disable-next-line
        WebSocket = null;
        return socket;
    }(),
    start: function browser_utilities_webSocket(callback, hashDevice) {
        const title = document.getElementById("title-bar"), scheme = location.protocol === "http:" ? "ws" : "wss", socket = new webSocket.sock(`${scheme}://localhost:${browser.network.ports.ws}/`, [
            `browser-${hashDevice}`
        ]), open = function browser_utilities_webSocket_socketOpen() {
            if (title.getAttribute("class") === "title offline") {
                location.reload();
            } else {
                title.setAttribute("class", "title");
                browser.socket = socket;
                if (callback !== null) {
                    callback();
                }
            }
        }, close = function browser_utilities_webSocket_socketClose() {
            if (browser.data.hashDevice !== "") {
                const device = document.getElementById(browser.data.hashDevice), agentList = document.getElementById("agentList"), active = agentList.getElementsByClassName("status-active");
                let a = active.length, parent;
                if (a > 0) {
                    do {
                        a = a - 1;
                        parent = active[a].parentNode;
                        parent.setAttribute("class", "offline");
                    }while (a > 0)
                }
                browser.socket = null;
                title.setAttribute("class", "title offline");
                title.getElementsByTagName("h1")[0].innerHTML = "Disconnected.";
                webSocket.send = null;
                if (device !== null) {
                    device.setAttribute("class", "offline");
                }
            }
        }, message = function browser_utilities_socketMessage(event) {
            if (typeof event.data !== "string") {
                return;
            }
            network.receive(event.data);
        };
        webSocket.hash = hashDevice;
        /* Handle Web Socket responses */ socket.onopen = open;
        socket.onmessage = message;
        socket.onclose = close;
        socket.onerror = webSocket.error;
        webSocket.send = function browser_utilities_webSocket_sendWrapper(data) {
            // connecting
            if (socket.readyState === 0) {
                setTimeout(function browser_utilities_webSocket_sendWrapper_delay() {
                    browser_utilities_webSocket_sendWrapper(data);
                }, 10);
            }
            // open
            if (socket.readyState === 1) {
                socket.send(JSON.stringify(data));
            }
        };
    }
};
export default webSocket;
